// Error codes returned by BASS_ErrorGetCode
long BASS_OK				= 0;	// all is OK
long BASS_ERROR_MEM			= 1;	// memory error
long BASS_ERROR_FILEOPEN	= 2;	// can't open the file
long BASS_ERROR_DRIVER		= 3;	// can't find a free/valid driver
long BASS_ERROR_BUFLOST		= 4;	// the sample buffer was lost
long BASS_ERROR_HANDLE		= 5;	// invalid handle
long BASS_ERROR_FORMAT		= 6;	// unsupported sample format
long BASS_ERROR_POSITION	= 7;	// invalid playback position
long BASS_ERROR_INIT		= 8;	// BASS_Init has not been successfully called
long BASS_ERROR_START		= 9;	// BASS_Start has not been successfully called
long BASS_ERROR_ALREADY		= 14;	// already initialized/paused/whatever
long BASS_ERROR_NOPAUSE		= 16;	// not paused
long BASS_ERROR_NOCHAN		= 18;	// can't get a free channel
long BASS_ERROR_ILLTYPE		= 19;	// an illegal type was specified
long BASS_ERROR_ILLPARAM	= 20;	// an illegal parameter was specified
long BASS_ERROR_NO3D		= 21;	// no 3D support
long BASS_ERROR_NOEAX		= 22;	// no EAX support
long BASS_ERROR_DEVICE		= 23;	// illegal device number
long BASS_ERROR_NOPLAY		= 24;	// not playing
long BASS_ERROR_FREQ		= 25;	// illegal sample rate
long BASS_ERROR_NOTFILE		= 27;	// the stream is not a file stream
long BASS_ERROR_NOHW		= 29;	// no hardware voices available
long BASS_ERROR_EMPTY		= 31;	// the MOD music has no sequence data
long BASS_ERROR_NONET		= 32;	// no internet connection could be opened
long BASS_ERROR_CREATE		= 33;	// couldn't create the file
long BASS_ERROR_NOFX		= 34;	// effects are not available
long BASS_ERROR_PLAYING		= 35;	// the channel is playing
long BASS_ERROR_NOTAVAIL	= 37;	// requested data is not available
long BASS_ERROR_DECODE		= 38;	// the channel is a "decoding channel"
long BASS_ERROR_DX			= 39;	// a sufficient DirectX version is not installed
long BASS_ERROR_TIMEOUT		= 40;	// connection timedout
long BASS_ERROR_FILEFORM	= 41;	// unsupported file format
long BASS_ERROR_SPEAKER		= 42;	// unavailable speaker
long BASS_ERROR_UNKNOWN		= -1;	// some other mystery error

// Initialization flags
long BASS_DEVICE_8BITS		= 1;	// use 8 bit resolution, else 16 bit
long BASS_DEVICE_MONO		= 2;	// use mono, else stereo
long BASS_DEVICE_3D			= 4;	// enable 3D functionality
/* If the BASS_DEVICE_3D flag is not specified when initilizing BASS,
then the 3D flags (BASS_SAMPLE_3D and BASS_MUSIC_3D) are ignored when
loading/creating a sample/stream/music. */
long BASS_DEVICE_LATENCY	= 256;	// calculate device latency (BASS_INFO struct)
long BASS_DEVICE_SPEAKERS 	= 2048;	// force enabling of speaker assignment

// DirectSound interfaces (for use with BASS_GetDSoundObject)
long BASS_OBJECT_DS			= 1;	// IDirectSound
long BASS_OBJECT_DS3DL		= 2;	// IDirectSound3DListener

// BASS_INFO flags (from DSOUND.H)
long DSCAPS_CONTINUOUSRATE	= 0x00000010;
/* supports all sample rates between min/maxrate */
long DSCAPS_EMULDRIVER		= 0x00000020;
/* device does NOT have hardware DirectSound support */
long DSCAPS_CERTIFIED		= 0x00000040;
/* device driver has been certified by Microsoft */
/* The following flags tell what type of samples are supported by HARDWARE
mixing, all these formats are supported by SOFTWARE mixing */
long DSCAPS_SECONDARYMONO	= 0x00000100;	// mono
long DSCAPS_SECONDARYSTEREO	= 0x00000200;	// stereo
long DSCAPS_SECONDARY8BIT	= 0x00000400;	// 8 bit
long DSCAPS_SECONDARY16BIT	= 0x00000800;	// 16 bit

// defines for formats field of BASS_RECORDINFO (from MMSYSTEM.H)
long WAVE_FORMAT_1M08       = 0x00000001;       /* 11.025 kHz, Mono,   8-bit  */
long WAVE_FORMAT_1S08       = 0x00000002;       /* 11.025 kHz, Stereo, 8-bit  */
long WAVE_FORMAT_1M16       = 0x00000004;       /* 11.025 kHz, Mono,   16-bit */
long WAVE_FORMAT_1S16       = 0x00000008;       /* 11.025 kHz, Stereo, 16-bit */
long WAVE_FORMAT_2M08       = 0x00000010;       /* 22.05  kHz, Mono,   8-bit  */
long WAVE_FORMAT_2S08       = 0x00000020;       /* 22.05  kHz, Stereo, 8-bit  */
long WAVE_FORMAT_2M16       = 0x00000040;       /* 22.05  kHz, Mono,   16-bit */
long WAVE_FORMAT_2S16       = 0x00000080;       /* 22.05  kHz, Stereo, 16-bit */
long WAVE_FORMAT_4M08       = 0x00000100;       /* 44.1   kHz, Mono,   8-bit  */
long WAVE_FORMAT_4S08       = 0x00000200;       /* 44.1   kHz, Stereo, 8-bit  */
long WAVE_FORMAT_4M16       = 0x00000400;       /* 44.1   kHz, Mono,   16-bit */
long WAVE_FORMAT_4S16       = 0x00000800;       /* 44.1   kHz, Stereo, 16-bit */

long BASS_SAMPLE_8BITS		= 1;	// 8 bit
long BASS_SAMPLE_FLOAT		= 256;	// 32-bit floating-point
long BASS_SAMPLE_MONO		= 2;	// mono
long BASS_SAMPLE_LOOP		= 4;	// looped
long BASS_SAMPLE_3D			= 8;	// 3D functionality enabled
long BASS_SAMPLE_SOFTWARE	= 16;	// it's NOT using hardware mixing
long BASS_SAMPLE_MUTEMAX	= 32;	// muted at max distance (3D only)
long BASS_SAMPLE_VAM		= 64;	// uses the DX7 voice allocation & management
long BASS_SAMPLE_FX			= 128;	// old implementation of DX8 effects are enabled
long BASS_SAMPLE_OVER_VOL	= 0x10000;	// override lowest volume
long BASS_SAMPLE_OVER_POS	= 0x20000;	// override longest playing
long BASS_SAMPLE_OVER_DIST	= 0x30000;	// override furthest from listener (3D only)

long BASS_STREAM_PRESCAN	= 0x20000;	// enable pin-point seeking (MP3/MP2/MP1)
long BASS_MP3_SETPOS		= 0x20000;	//BASS_STREAM_PRESCAN;
long BASS_STREAM_AUTOFREE	= 0x40000;	// automatically free the stream when it stop/ends
long BASS_STREAM_RESTRATE	= 0x80000;	// restrict the download rate of internet file streams
long BASS_STREAM_BLOCK		= 0x100000; // download/play internet file stream in small blocks
long BASS_STREAM_DECODE		= 0x200000; // don't play the stream, only decode (BASS_ChannelGetData)
long BASS_STREAM_STATUS		= 0x800000; // give server status info (HTTP/ICY tags) in DOWNLOADPROC

long BASS_MUSIC_FLOAT		= 256;		//BASS_SAMPLE_FLOAT; // 32-bit floating-point
long BASS_MUSIC_MONO		= 2;		//BASS_SAMPLE_MONO; // force mono mixing (less CPU usage)
long BASS_MUSIC_LOOP		= 4;		//BASS_SAMPLE_LOOP; // loop music
long BASS_MUSIC_3D			= 8;		//BASS_SAMPLE_3D; // enable 3D functionality
long BASS_MUSIC_FX			= 128;		//BASS_SAMPLE_FX; // enable old implementation of DX8 effects
long BASS_MUSIC_AUTOFREE	= 0x40000;	//BASS_STREAM_AUTOFREE; // automatically free the music when it stop/ends
long BASS_MUSIC_DECODE		= 0x200000;	//BASS_STREAM_DECODE; // don't play the music, only decode (BASS_ChannelGetData)
long BASS_MUSIC_PRESCAN		= 0x20000;	//BASS_STREAM_PRESCAN;	// calculate playback length
long BASS_MUSIC_CALCLEN		= 0x20000;	//BASS_MUSIC_PRESCAN;
long BASS_MUSIC_RAMP		= 0x200;	// normal ramping
long BASS_MUSIC_RAMPS		= 0x400;	// sensitive ramping
long BASS_MUSIC_SURROUND	= 0x800;	// surround sound
long BASS_MUSIC_SURROUND2	= 0x1000;	// surround sound (mode 2)
long BASS_MUSIC_FT2MOD		= 0x2000;	// play .MOD as FastTracker 2 does
long BASS_MUSIC_PT1MOD		= 0x4000;	// play .MOD as ProTracker 1 does
long BASS_MUSIC_NONINTER	= 0x10000;	// non-interpolated mixing
long BASS_MUSIC_POSRESET	= 0x8000;	// stop all notes when moving position
long BASS_MUSIC_POSRESETEX	= 0x400000; // stop all notes and reset bmp/etc when moving position
long BASS_MUSIC_STOPBACK	= 0x80000;	// stop the music on a backwards jump effect
long BASS_MUSIC_NOSAMPLE	= 0x100000;	// don't load the samples

// Speaker assignment flags
long BASS_SPEAKER_FRONT		= 0x1000000;	// front speakers
long BASS_SPEAKER_REAR		= 0x2000000;	// rear/side speakers
long BASS_SPEAKER_CENLFE	= 0x3000000;	// center & LFE speakers (5.1)
long BASS_SPEAKER_REAR2		= 0x4000000;	// rear center speakers (7.1)
long BASS_SPEAKER_LEFT		= 0x10000000;	// modifier: left
long BASS_SPEAKER_RIGHT		= 0x20000000;	// modifier: right
/*
long BASS_SPEAKER_FRONTLEFT = BASS_SPEAKER_FRONT|BASS_SPEAKER_LEFT;
long BASS_SPEAKER_FRONTRIGHT = BASS_SPEAKER_FRONT|BASS_SPEAKER_RIGHT;
long BASS_SPEAKER_REARLEFT  = BASS_SPEAKER_REAR|BASS_SPEAKER_LEFT;
long BASS_SPEAKER_REARRIGHT = BASS_SPEAKER_REAR|BASS_SPEAKER_RIGHT;
long BASS_SPEAKER_CENTER	= BASS_SPEAKER_CENLFE|BASS_SPEAKER_LEFT;
long BASS_SPEAKER_LFE		= BASS_SPEAKER_CENLFE|BASS_SPEAKER_RIGHT;
long BASS_SPEAKER_REAR2LEFT = BASS_SPEAKER_REAR2|BASS_SPEAKER_LEFT;
long BASS_SPEAKER_REAR2RIGHT = BASS_SPEAKER_REAR2|BASS_SPEAKER_RIGHT;
*/
long BASS_UNICODE			= 0x80000000;

long BASS_RECORD_PAUSE		= 0x8000;	// start recording paused

long BASS_VAM_HARDWARE		= 1;
long BASS_VAM_SOFTWARE		= 2;
long BASS_VAM_TERM_TIME		= 4;
long BASS_VAM_TERM_DIST		= 8;
long BASS_VAM_TERM_PRIO		= 16;

// BASS_CHANNELINFO types
long BASS_CTYPE_SAMPLE		= 1;
long BASS_CTYPE_RECORD		= 2;
long BASS_CTYPE_STREAM		= 0x10000;
long BASS_CTYPE_STREAM_WAV	= 0x10001;
long BASS_CTYPE_STREAM_OGG	= 0x10002;
long BASS_CTYPE_STREAM_MP1	= 0x10003;
long BASS_CTYPE_STREAM_MP2	= 0x10004;
long BASS_CTYPE_STREAM_MP3	= 0x10005;
long BASS_CTYPE_STREAM_AIFF	= 0x10006;
long BASS_CTYPE_MUSIC_MOD	= 0x20000;
long BASS_CTYPE_MUSIC_MTM	= 0x20001;
long BASS_CTYPE_MUSIC_S3M	= 0x20002;
long BASS_CTYPE_MUSIC_XM	= 0x20003;
long BASS_CTYPE_MUSIC_IT	= 0x20004;
long BASS_CTYPE_MUSIC_MO3	= 0x00100;	// mo3 flag

// 3D channel modes
long BASS_3DMODE_NORMAL		= 0;
long BASS_3DMODE_RELATIVE	= 1;
long BASS_3DMODE_OFF		= 2;

// software 3D mixing algorithm modes (used with BASS_Set3DAlgorithm)
long BASS_3DALG_DEFAULT		= 0;
long BASS_3DALG_OFF			= 1;
long BASS_3DALG_FULL		= 2;
long BASS_3DALG_LIGHT		= 3;

long BASS_STREAMPROC_END	= 0x80000000;	// end of user stream flag

// BASS_StreamGetFilePosition modes
long BASS_FILEPOS_CURRENT	= 0;
long BASS_FILEPOS_DECODE	= 0; //BASS_FILEPOS_CURRENT;
long BASS_FILEPOS_DOWNLOAD	= 1;
long BASS_FILEPOS_END		= 2;
long BASS_FILEPOS_START		= 3;

// STREAMFILEPROC actions
long BASS_FILE_CLOSE		= 0;
long BASS_FILE_READ			= 1;
long BASS_FILE_LEN			= 3;
long BASS_FILE_SEEK			= 4;

long BASS_SYNC_POS			= 0;
long BASS_SYNC_END			= 2;
long BASS_SYNC_META			= 4;
long BASS_SYNC_SLIDE		= 5;
long BASS_SYNC_STALL		= 6;
long BASS_SYNC_DOWNLOAD		= 7;
long BASS_SYNC_FREE			= 8;
long BASS_SYNC_MUSICPOS		= 10;
long BASS_SYNC_MUSICINST	= 1;
long BASS_SYNC_MUSICFX		= 3;
long BASS_SYNC_MESSAGE		= 0x20000000;	// FLAG: post a Windows message (instead of callback)
long BASS_SYNC_MIXTIME		= 0x40000000;	// FLAG: sync at mixtime, else at playtime
long BASS_SYNC_ONETIME		= 0x80000000;	// FLAG: sync only once, else continuously

// BASS_ChannelGetData flags
long BASS_DATA_AVAILABLE	= 0;			// query how much data is buffered
long BASS_DATA_FLOAT		= 0x40000000;	// flag: return floating-point sample data
long BASS_DATA_FFT512		= 0x80000000;	// 512 sample FFT
long BASS_DATA_FFT1024		= 0x80000001;	// 1024 FFT
long BASS_DATA_FFT2048		= 0x80000002;	// 2048 FFT
long BASS_DATA_FFT4096		= 0x80000003;	// 4096 FFT
long BASS_DATA_FFT_INDIVIDUAL = 0x10;	// FFT flag: FFT for each channel, else all combined
long BASS_DATA_FFT_NOWINDOW   = 0x20;	// FFT flag: no Hanning window

// BASS_StreamGetTags types : what's returned
long BASS_TAG_ID3		= 0;	// ID3v1 tags : 128 byte block
long BASS_TAG_ID3V2		= 1;	// ID3v2 tags : variable length block
long BASS_TAG_OGG		= 2;	// OGG comments : array of null-terminated strings
long BASS_TAG_HTTP		= 3;	// HTTP headers : array of null-terminated strings
long BASS_TAG_ICY		= 4;	// ICY headers : array of null-terminated strings
long BASS_TAG_META		= 5;	// ICY metadata : null-terminated string

// BASS_MusicSet/GetAttribute options
long BASS_MUSIC_ATTRIB_AMPLIFY	= 0;
long BASS_MUSIC_ATTRIB_PANSEP	= 1;
long BASS_MUSIC_ATTRIB_PSCALER	= 2;
long BASS_MUSIC_ATTRIB_BPM		= 3;
long BASS_MUSIC_ATTRIB_SPEED	= 4;
long BASS_MUSIC_ATTRIB_VOL_GLOBAL = 5;
long BASS_MUSIC_ATTRIB_VOL_CHAN = 0x100; // + channel #
long BASS_MUSIC_ATTRIB_VOL_INST = 0x200; // + instrument #

long BASS_FX_PHASE_NEG_180        = 0;
long BASS_FX_PHASE_NEG_90         = 1;
long BASS_FX_PHASE_ZERO           = 2;
long BASS_FX_PHASE_90             = 3;
long BASS_FX_PHASE_180            = 4;

// BASS_ChannelIsActive return values
long BASS_ACTIVE_STOPPED	= 0;
long BASS_ACTIVE_PLAYING	= 1;
long BASS_ACTIVE_STALLED	= 2;
long BASS_ACTIVE_PAUSED		= 3;

// BASS_ChannelIsSliding return flags
long BASS_SLIDE_FREQ		= 1;
long BASS_SLIDE_VOL			= 2;
long BASS_SLIDE_PAN			= 4;

// BASS_RecordSetInput flags
long BASS_INPUT_OFF		= 0x10000;
long BASS_INPUT_ON		= 0x20000;
long BASS_INPUT_LEVEL	= 0x40000;

long BASS_INPUT_TYPE_MASK		= 0xff000000;
long BASS_INPUT_TYPE_UNDEF		= 0x00000000;
long BASS_INPUT_TYPE_DIGITAL	= 0x01000000;
long BASS_INPUT_TYPE_LINE		= 0x02000000;
long BASS_INPUT_TYPE_MIC		= 0x03000000;
long BASS_INPUT_TYPE_SYNTH		= 0x04000000;
long BASS_INPUT_TYPE_CD			= 0x05000000;
long BASS_INPUT_TYPE_PHONE		= 0x06000000;
long BASS_INPUT_TYPE_SPEAKER	= 0x07000000;
long BASS_INPUT_TYPE_WAVE		= 0x08000000;
long BASS_INPUT_TYPE_AUX		= 0x09000000;
long BASS_INPUT_TYPE_ANALOG		= 0x0a000000;

// BASS_Set/GetConfig options
long BASS_CONFIG_BUFFER			= 0;
long BASS_CONFIG_UPDATEPERIOD	= 1;
long BASS_CONFIG_MAXVOL			= 3;
long BASS_CONFIG_GVOL_SAMPLE	= 4;
long BASS_CONFIG_GVOL_STREAM	= 5;
long BASS_CONFIG_GVOL_MUSIC		= 6;
long BASS_CONFIG_CURVE_VOL		= 7;
long BASS_CONFIG_CURVE_PAN		= 8;
long BASS_CONFIG_FLOATDSP		= 9;
long BASS_CONFIG_3DALGORITHM	= 10;
long BASS_CONFIG_NET_TIMEOUT	= 11;
long BASS_CONFIG_NET_BUFFER		= 12;
long BASS_CONFIG_PAUSE_NOPLAY	= 13;
long BASS_CONFIG_NET_NOPROXY	= 14;
long BASS_CONFIG_NET_PREBUF		= 15;
long BASS_CONFIG_NET_AGENT		= 16;
